==> micro-website-base-core-2.0.7-sources.jar: com/ptteng/sca/micro/common/client/UserRoleRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.micro.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.micro.common.model.UserRoleRelation;
import com.ptteng.micro.common.service.UserRoleRelationService;

import java.util.List;
import java.util.Map;

public class UserRoleRelationSCAClient implements UserRoleRelationService {

    private UserRoleRelationService userRoleRelationService;

	public UserRoleRelationService getUserRoleRelationService() {
		return userRoleRelationService;
	}
	
	
	public void setUserRoleRelationService(UserRoleRelationService userRoleRelationService) {
		this.userRoleRelationService =userRoleRelationService;
	}
	
	
			   
		@Override
		public Long insert(UserRoleRelation userRoleRelation)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.insert(userRoleRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<UserRoleRelation> insertList(List<UserRoleRelation> userRoleRelationList)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.insertList(userRoleRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(UserRoleRelation userRoleRelation)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.update(userRoleRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<UserRoleRelation> userRoleRelationList)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.updateList(userRoleRelationList);
		          
		
		}	
		  
    	   
		@Override
		public UserRoleRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<UserRoleRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserRoleRelationIdsByUserIdAndRoleIdAndMerchantId(Long userId,Long roleId,Long merchantId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.getUserRoleRelationIdsByUserIdAndRoleIdAndMerchantId(userId,roleId,merchantId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserRoleRelationIdsByUserIdAndMerchantId(Long userId,Long merchantId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.getUserRoleRelationIdsByUserIdAndMerchantId(userId,merchantId,start,limit);
	
	
	}

    @Override
    public List<Long> getUserRoleRelationIdsByRoleId(Long roleId, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
        return userRoleRelationService.getUserRoleRelationIdsByRoleId(roleId,start,limit);
    }


    /**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserRoleRelationIdsByUserIdAndRoleIdAndMerchantId(Long userId,Long roleId,Long merchantId)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.countUserRoleRelationIdsByUserIdAndRoleIdAndMerchantId(userId,roleId,merchantId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserRoleRelationIdsByUserIdAndMerchantId(Long userId,Long merchantId)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.countUserRoleRelationIdsByUserIdAndMerchantId(userId,merchantId);
	
	
	}
	
		
	
		@Override
	public List<Long> getUserRoleRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userRoleRelationService.getUserRoleRelationIds(start, limit);
	}

	@Override
	public Integer countUserRoleRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userRoleRelationService.countUserRoleRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userRoleRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userRoleRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   userRoleRelationService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.userRoleRelationService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}
//	@Override
//	public Object getMapListByDynamicCondition(Class clz,
//			Map<String, Object> conditions, Integer start, Integer limit)
//			throws ServiceException, ServiceDaoException {
//
//		return this.userRoleRelationService.getMapListByDynamicCondition(clz, conditions, start, limit);
//	}


 
}

==> micro-website-base-core-2.1.5-sources.jar: com/ptteng/sca/micro/common/client/UserRoleRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.micro.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.micro.common.model.UserRoleRelation;
import com.ptteng.micro.common.service.UserRoleRelationService;

import java.util.List;
import java.util.Map;

public class UserRoleRelationSCAClient implements UserRoleRelationService {

    private UserRoleRelationService userRoleRelationService;

	public UserRoleRelationService getUserRoleRelationService() {
		return userRoleRelationService;
	}
	
	
	public void setUserRoleRelationService(UserRoleRelationService userRoleRelationService) {
		this.userRoleRelationService =userRoleRelationService;
	}
	
	
			   
		@Override
		public Long insert(UserRoleRelation userRoleRelation)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.insert(userRoleRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<UserRoleRelation> insertList(List<UserRoleRelation> userRoleRelationList)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.insertList(userRoleRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(UserRoleRelation userRoleRelation)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.update(userRoleRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<UserRoleRelation> userRoleRelationList)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.updateList(userRoleRelationList);
		          
		
		}	
		  
    	   
		@Override
		public UserRoleRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<UserRoleRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserRoleRelationIdsByUserIdAndRoleIdAndMerchantId(Long userId,Long roleId,Long merchantId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.getUserRoleRelationIdsByUserIdAndRoleIdAndMerchantId(userId,roleId,merchantId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserRoleRelationIdsByUserIdAndMerchantId(Long userId,Long merchantId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.getUserRoleRelationIdsByUserIdAndMerchantId(userId,merchantId,start,limit);
	
	
	}

    @Override
    public List<Long> getUserRoleRelationIdsByRoleId(Long roleId, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
        return userRoleRelationService.getUserRoleRelationIdsByRoleId(roleId,start,limit);
    }


    /**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserRoleRelationIdsByUserIdAndRoleIdAndMerchantId(Long userId,Long roleId,Long merchantId)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.countUserRoleRelationIdsByUserIdAndRoleIdAndMerchantId(userId,roleId,merchantId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserRoleRelationIdsByUserIdAndMerchantId(Long userId,Long merchantId)throws ServiceException, ServiceDaoException{
		
		return userRoleRelationService.countUserRoleRelationIdsByUserIdAndMerchantId(userId,merchantId);
	
	
	}
	
		
	
		@Override
	public List<Long> getUserRoleRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userRoleRelationService.getUserRoleRelationIds(start, limit);
	}

	@Override
	public Integer countUserRoleRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userRoleRelationService.countUserRoleRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userRoleRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userRoleRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   userRoleRelationService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.userRoleRelationService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}

	@Override
	public Object getMapListByDynamicCondition(Class aClass, Map<String, Object> map, Integer integer, Integer integer1) throws ServiceException, ServiceDaoException {
		return null;
	}
//	@Override
//	public Object getMapListByDynamicCondition(Class clz,
//			Map<String, Object> conditions, Integer start, Integer limit)
//			throws ServiceException, ServiceDaoException {
//
//		return this.userRoleRelationService.getMapListByDynamicCondition(clz, conditions, start, limit);
//	}


 
}
